@@ -1,14 +1,16 @@
 ## File Name: reglca_calc_individual_posterior.R
-## File Version: 0.10
+## File Version: 0.116
 
 reglca_calc_individual_posterior <- function(class_probs, p.xi.aj, N, nclasses, weights, W,
-            G, ind_groups, N_groups)
+            G, ind_groups, N_groups, min_class_probs=1e-3)
 {
     #--- single group
     if (G==1){
         p.aj.xi <- cdm_matrix2( class_probs, nrow=N ) * p.xi.aj
         p.aj.xi <- p.aj.xi / rowSums( p.aj.xi )
         class_probs <- colSums( p.aj.xi * weights / W )
+        class_probs <- reglca_bound_classprobs(class_probs=class_probs,
+                            min_class_probs=min_class_probs)
     }
     #--- multiple groups
     if (G>1){
@@ -22,6 +24,8 @@ reglca_calc_individual_posterior <- function(class_probs, p.xi.aj, N, nclasses,
             ind_gg <- ind_groups[[gg]]
             weights_gg <- weights[ind_gg]
             class_probs[,gg] <- colSums( p.aj.xi[ind_gg,] * weights_gg / W[gg] )
+            class_probs[,gg] <- reglca_bound_classprobs(class_probs=class_probs[,gg],
+                            min_class_probs=min_class_probs)
         }
     }
     #---- OUTPUT
