@@ -1,9 +1,10 @@
 ## File Name: summary_sink.R
-## File Version: 0.06
+## File Version: 0.07
 
 summary_sink <- function( object, file, append=FALSE, ...)
 {
     osink( file=file, suffix="__SUMMARY.Rout", append=append )
-    print( summary(object=object, ... ) )
+    # print( summary(object=object, ... ) )
+    summary(object=object, ... )
     csink(file=file)
 }
